# -*- coding: utf-8 -*-
"""
Pygifconvt: a very serious Python library for image to gif converter

# TODO
파이썬 기초에 나온단다.
__init__ 파일이 없으면, 패키지로 인식하지 않음.

- 설치 방법
pip install pypi
pip install github
"""
__title__ = "Pygifconvt"
__author__ = "Eunki7"
__license__ = "MIT License"
__copyright__ = "Copyright 2020 Eunki7"
